@@ -3,37 +3,46 @@
 plot.STM <- function(x, 
                      type=c("summary", "labels", "perspectives"),
                      n=NULL, topics=NULL,
-                     labeltype=c("prob", "frex", "lift", "score"), frexw=.5,
+                     labeltype="prob", frexw=.5,
                      main=NULL, xlim=NULL, ylim=NULL, xlab=NULL, family="",
                      width=80, 
-                     covarlevels=NULL, plabels=NULL, text.cex=1,
+                     covarlevels=NULL, plabels=NULL, text.cex=1, custom.labels=NULL,
                      ...){
   model <- x
   type <- match.arg(type)
-  labeltype <- match.arg(labeltype)
   if(is.null(n)) n <- switch(type, 
                              summary=3, 
                              labels=20,
                              perspectives=25)
   contentcov <- length(model$beta$logbeta)!=1
-  if(type %in% c("summary", "labels")) {
-    if(is.null(topics)) topics <- 1:model$settings$dim$K
-    #compute the labels
-    lab <- labelTopics(model, topics=topics, n = n, frexweight=frexw)
-    if(contentcov) {
-      lab <- lab$topics
-    } else {
-      lab <- lab[[labeltype]]
+  
+  if(labeltype!="custom"){
+    if(type %in% c("summary", "labels")) {
+      if(is.null(topics)) topics <- 1:model$settings$dim$K
+                                        #compute the labels
+      lab <- labelTopics(model, topics=topics, n = n, frexweight=frexw)
+      if(contentcov) {
+        lab <- lab$topics
+      } else {
+        lab <- lab[[labeltype]]
+      }    
     }
-    lab <- apply(lab, 1, commas)
-    if(type=="summary") lab <- sprintf("Topic %i: %s", topics, lab)
+  }
+  
+  if(labeltype=="custom"){
+    lab <- custom.labels
   }
   
   # Summary Plot
   # note at one point there was a threshold metric for choosing the number of words but
   # it was specific to highest frequency words so I opted to just remove it.
   if(type=="summary") {
-    frequency <- colMeans(model$theta)
+    if(labeltype!="custom"){
+      lab <- apply(lab, 1, commas)
+      lab <- sprintf("Topic %i: %s", 1:length(lab), lab)
+      lab <- lab[topics]
+    }
+    frequency <- colMeans(model$theta[,topics])
     invrank <- order(frequency, decreasing=FALSE)
     if(is.null(xlim)) xlim <- c(0,min(2*max(frequency), 1))
     if(is.null(ylim)) ylim <- c(0,length(topics))
@@ -46,22 +55,23 @@ plot.STM <- function(x,
          ylab=ylab, xlab=xlab, ...)
     for(i in 1:length(invrank)) {
       lines(c(0,frequency[invrank[i]]), c(i, i))
-      text(frequency[invrank[i]]+.01, i , lab[invrank[i]],family=family,pos=4, cex=text.cex)
+      text(frequency[invrank[i]]+.05, i , lab[invrank[i]],family=family,pos=4, cex=text.cex)
     }
   }
   
   # Labels Plot
   if(type=="labels") {
     if(contentcov) stop("labels plot not yet implemented with content covariates.  See labelTopics for labels.")
-    plot(c(0,0), type="n", 
+    plot(c(0,0), type="n", main=main,
          ylim=c(1,length(topics)+.9), 
          xlim=c(1,n+1), 
-         xaxt="n", yaxt="n", xlab="", ylab="")
+         xaxt="n", yaxt="n", xlab="", ylab="",...)
+    if(labeltype!="custom") lab <- apply(lab, 1, commas)
     for(i in 1:length(topics)){
       if(i!=length(topics)) lines(c(-1,n+3), c(i+1,i+1), lty=2)
       string <- paste0(strwrap(lab[rev(topics)[i]], width=width),collapse="\n")
       text(n/2, i + .5, 
-           paste("Topic", rev(topics)[i], ":  \n", string), family=family)
+           paste("Topic", rev(topics)[i], ":  \n", string), family=family, cex=text.cex)
     }
   }
   
@@ -128,16 +138,15 @@ plot.STM <- function(x,
     
     #Take the probability for the topic they are the highest in.  
     # Scale it so the max is 4 times as large, and then take the inverse hyperbolic sine func.
-    # this basically has the effect of flattening it out a bit so the gian things aren't huge.
+    # this basically has the effect of flattening it out a bit so the giant things aren't huge.
     scale <- pmax(exp(left[words]) + exp(right[words]))
     scale <- asinh((scale/max(scale))*4)
     
     diff <- exp(left[words]) - exp(right[words])
     diff <- diff/max(abs(diff))
     #Create the plot
-    par(xpd=TRUE)
     plot(c(0,0), xlim=c(min(diff) - .1, max(diff)+.1), ylim=c(-2*length(diff),6*length(diff)), type="n", 
-         xaxt="n", xlab="", main="", yaxt="n", ylab="", bty="n")
+         xaxt="n", xlab="", main=main, yaxt="n", ylab="", bty="n",...)
     segments(0,0, 0, -2*length(diff),lty=2)
     rand <- sample(seq(1, 6*length(diff),by=2), length(diff), replace=F)
     thresh <- .1
@@ -145,7 +154,7 @@ plot.STM <- function(x,
     posdiff <- diff*(diff>thresh)
     middiff <- diff*(diff <thresh & diff > -thresh)
     colors <- rgb(posdiff+.75, .75, -negdiff+.75, maxColorValue=2)
-    text(diff, rand, model$vocab[words], cex=scale, col=colors)
+    text(diff, rand, model$vocab[words], cex=scale, col=colors, family=family)
     
     #X-axis
     text(.75*min(diff), -length(diff), as.character(plabels[2]), 
